@@ -28,19 +28,14 @@
 #ifndef OPENSHOT_QIMAGE_READER_H
 #define OPENSHOT_QIMAGE_READER_H
 
-#include "ReaderBase.h"
-
 #include <cmath>
 #include <ctime>
 #include <iostream>
 #include <omp.h>
 #include <stdio.h>
-#include <tr1/memory>
-#include <QtCore/QString>
-#include <QtGui/QImage>
-#include <QtGui/QPainter>
-#include "CacheMemory.h"
+#include <memory>
 #include "Exceptions.h"
+#include "ReaderBase.h"
 
 using namespace std;
 
@@ -57,7 +52,7 @@ namespace openshot
 	 * r.Open(); // Open the reader
 	 *
 	 * // Get frame number 1 from the video
-	 * tr1::shared_ptr<Frame> f = r.GetFrame(1);
+	 * std::shared_ptr<Frame> f = r.GetFrame(1);
 	 *
 	 * // Now that we have an openshot::Frame object, lets have some fun!
 	 * f->Display(); // Display the frame on the screen
@@ -70,20 +65,20 @@ namespace openshot
 	{
 	private:
 		string path;
-		tr1::shared_ptr<QImage> image; ///> Original image (full quality)
-		tr1::shared_ptr<QImage> cached_image; ///> Scaled for performance
+		std::shared_ptr<QImage> image; ///> Original image (full quality)
+		std::shared_ptr<QImage> cached_image; ///> Scaled for performance
 		bool is_open;
 
 	public:
 
 		/// Constructor for QtImageReader.  This automatically opens the media file and loads
 		/// frame 1, or it throws one of the following exceptions.
-		QtImageReader(string path) throw(InvalidFile);
+		QtImageReader(string path);
 
 		/// Constructor for QtImageReader.  This only opens the media file to inspect it's properties
 		/// if inspect_reader=true. When not inspecting the media file, it's much faster, and useful
 		/// when you are inflating the object using JSON after instantiating it.
-		QtImageReader(string path, bool inspect_reader) throw(InvalidFile);
+		QtImageReader(string path, bool inspect_reader);
 
 		/// Close File
 		void Close();
@@ -96,7 +91,7 @@ namespace openshot
 		///
 		/// @returns The requested frame (containing the image)
 		/// @param requested_frame The frame number that is requested.
-		tr1::shared_ptr<Frame> GetFrame(long int requested_frame) throw(ReaderClosed);
+		std::shared_ptr<Frame> GetFrame(int64_t requested_frame);
 
 		/// Determine if reader is open or closed
 		bool IsOpen() { return is_open; };
@@ -106,12 +101,12 @@ namespace openshot
 
 		/// Get and Set JSON methods
 		string Json(); ///< Generate JSON string of this object
-		void SetJson(string value) throw(InvalidJSON); ///< Load JSON string into this object
+		void SetJson(string value); ///< Load JSON string into this object
 		Json::Value JsonValue(); ///< Generate Json::JsonValue for this object
-		void SetJsonValue(Json::Value root) throw(InvalidFile); ///< Load Json::JsonValue into this object
+		void SetJsonValue(Json::Value root); ///< Load Json::JsonValue into this object
 
 		/// Open File - which is called by the constructor automatically
-		void Open() throw(InvalidFile);
+		void Open();
 	};
 
 }
