@@ -35,6 +35,7 @@
 #include <sstream>
 #include "CacheMemory.h"
 #include "ChannelLayouts.h"
+#include "ClipBase.h"
 #include "Fraction.h"
 #include "Frame.h"
 #include "Json.h"
@@ -62,7 +63,7 @@ namespace openshot
 		bool has_audio;				///< Determines if this file has an audio stream
 		bool has_single_image;		///< Determines if this file only contains a single image
 		float duration;				///< Length of time (in seconds)
-		long long file_size;		///< Size of file (in bytes)
+		int64_t file_size;		///< Size of file (in bytes)
 		int height;					///< The height of the video (in pixels)
 		int width;					///< The width of the video (in pixesl)
 		int pixel_format;			///< The pixel format (i.e. YUV420P, RGB24, etc...)
@@ -71,7 +72,7 @@ namespace openshot
 		Fraction pixel_ratio;		///< The pixel ratio of the video stream as a fraction (i.e. some pixels are not square)
 		Fraction display_ratio;		///< The ratio of width to height of the video stream (i.e. 640x480 has a ratio of 4/3)
 		string vcodec;				///< The name of the video codec used to encode / decode the video stream
-		long int video_length;		///< The number of frames in the video stream
+		int64_t video_length;		///< The number of frames in the video stream
 		int video_stream_index;		///< The index of the video stream
 		Fraction video_timebase;	///< The video timebase determines how long each frame stays on the screen
 		bool interlaced_frame;		// Are the contents of this frame interlaced
@@ -83,6 +84,7 @@ namespace openshot
 		ChannelLayout channel_layout;	///< The channel layout (mono, stereo, 5 point surround, etc...)
 		int audio_stream_index;		///< The index of the audio stream
 		Fraction audio_timebase;	///< The audio timebase determines how long each audio packet should be played
+		std::map<string, string> metadata;	///< An optional map/dictionary of metadata for this reader
 	};
 
 	/**
@@ -98,9 +100,7 @@ namespace openshot
 		/// Section lock for multiple threads
 	    CriticalSection getFrameCriticalSection;
 	    CriticalSection processingCriticalSection;
-
-		int max_width; ///< The maximum image width needed by this clip (used for optimizations)
-		int max_height; ///< The maximium image height needed by this clip (used for optimizations)
+		ClipBase* parent;
 
 	public:
 
@@ -110,6 +110,12 @@ namespace openshot
 		/// Information about the current media file
 		ReaderInfo info;
 
+		/// Parent clip object of this reader (which can be unparented and NULL)
+		ClipBase* GetClip();
+
+		/// Set parent clip object of this reader
+		void SetClip(ClipBase* clip);
+
 		/// Close the reader (and any resources it was consuming)
 		virtual void Close() = 0;
 
@@ -125,7 +131,7 @@ namespace openshot
 		///
 		/// @returns The requested frame of video
 		/// @param[in] number The frame number that is requested.
-		virtual std::shared_ptr<Frame> GetFrame(long int number) = 0;
+		virtual std::shared_ptr<Frame> GetFrame(int64_t number) = 0;
 
 		/// Determine if reader is open or closed
 		virtual bool IsOpen() = 0;
@@ -135,13 +141,10 @@ namespace openshot
 
 		/// Get and Set JSON methods
 		virtual string Json() = 0; ///< Generate JSON string of this object
-		virtual void SetJson(string value) throw(InvalidJSON) = 0; ///< Load JSON string into this object
+		virtual void SetJson(string value) = 0; ///< Load JSON string into this object
 		virtual Json::Value JsonValue() = 0; ///< Generate Json::JsonValue for this object
 		virtual void SetJsonValue(Json::Value root) = 0; ///< Load Json::JsonValue into this object
 
-		/// Set Max Image Size (used for performance optimization)
-		void SetMaxSize(int width, int height) { max_width = width; max_height = height; };
-
 		/// Open the reader (and start consuming resources, such as images or video files)
 		virtual void Open() = 0;
 	};
